package com.jcg.paginationsortingexample;

import java.util.List;

import static org.assertj.core.api.Assertions.assertThat;
import static org.junit.jupiter.api.Assertions.assertEquals;

import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.orm.jpa.DataJpaTest;
import org.springframework.data.domain.Page;

import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;

/**
 *
 * @author omozegieaziegbe
 */
@DataJpaTest
public class BookRepositoryTest {

    @Autowired
    private BookRepository bookRepository;
    
    @Test
    public void testRepository() {
        
        // page 1 (First Page), size 5, sort by title, asc
      Sort sort = Sort.by(Sort.Direction.ASC, "title");
      Pageable pageable = PageRequest.of(0, 5, sort);

      Page<Book> result = bookRepository.findAll(pageable);

      List<Book> books = result.getContent();

      assertEquals(5, books.size());

      assertThat(result).extracting(Book::getTitle)
              .containsExactlyInAnyOrder(
                      "Age of Reason", "Core HTML5 Canvas", "Core Java Fundamentals", "Java EE 6 Platform with Glassfish 3", "Java EE 7 Essentials");

      // page 2 (Second Page), size 5, sort by title, asc
      Pageable secondPageable = PageRequest.of(1, 5, sort);

      Page<Book> result2 = bookRepository.findAll(secondPageable);

      List<Book> books2 = result2.getContent();

      assertEquals(5, books2.size());

      assertThat(result2).extracting(Book::getTitle)
              .containsExactlyInAnyOrder(
                      "JavaScript Enlightenment", "JavaScript and JQuery", "Pro JavaScript for Web Apps", 
                      "Real World Java EE Patterns", "Smashing CSS");
    }

}
